@@ -27,12 +27,12 @@ namespace KDiamond
 class View : public QGraphicsView
 {
 public:
-    View(QWidget *parent = 0);
+    explicit View(QWidget *parent = 0);
 
     void setScene(QGraphicsScene *scene);
 protected:
-    virtual void resizeEvent(QResizeEvent *event);
-    virtual void wheelEvent(QWheelEvent *event);
+    void resizeEvent(QResizeEvent *event) Q_DECL_OVERRIDE;
+    void wheelEvent(QWheelEvent *event) Q_DECL_OVERRIDE;
 };
 
 }
